<!--{#
This is a sample page to show how you can customize the top of post's feed page 
Copy this file to your project's template directory.
You can add for example your page's logo or some text, whatever.
#}-->
{% load i18n %}
<h1>{% trans 'Write a post' %}</h1>
