<!--{#
This is a sample page to show how you can customize the header of post's feed page 
Copy this file to your project's template directory.
You can add here your custom title, css, js, meta tags, etecetera...
#}-->
{% load i18n %}
<title>{% trans 'Write a post' %}</title>
