<!--{#
This is a sample page to show how to customize the top of user's profile page 
Copy this file to your project's template directory.
You can add for example your page's logo or some text, whatever.
#}-->
