{% load static %}
{% block header %}
    <script application="javascript" src="{% static '/social_layer/js/social_layer.js' %}"></script>
    <link rel="stylesheet" href="{% static '/social_layer/css/social_layer.css' %}"/>
{% endblock header %}

{% block content %}
{% endblock content %}
