# Generated by Django 3.0.6 on 2020-11-21 15:08

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('social_layer', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='socialprofile',
            name='last_actv',
            field=models.DateTimeField(default=django.utils.timezone.localtime),
        ),
    ]
