{% load i18n %}

<div class="full-width sl-likes">
{% with comment_section as cs %}
    <a href="javascript:sl_like('{% url 'social_layer:like_post' cs.pk 'like' %}?ajx', 'like_{{cs.id}}');" >
        <span id="like_{{ cs.pk }}" >{{ cs.count_likes|default:'' }}</span>
        <i class="fas fa-thumbs-up"></i>
    </a>
    <a href="javascript:sl_like('{% url 'social_layer:like_post' cs.pk 'dislike' %}', 'dislike_{{cs.id}}');" >
        <span id="dislike_{{ cs.pk }}" >{{ cs.count_dislikes|default:'' }}</span>
        <i class="fas fa-thumbs-down"></i>
    </a>
    <a href="?show-comments" rel="nofollow">
        {% if cs.count_replies > 0 %}
            <i class="fas fa-sort-down"></i>
            ({{ cs.count_replies }})
        {% endif %}
    </a>
    <a href="{{ cs.get_url }}" rel="nofollow" >
        {% trans 'reply' %}
    </a>
{% endwith %}
</div>
