{% extends 'social_layer/base.html' %}
{% load i18n %}
{% load infinite_scroll %}

{% block header%}
    {{ block.super }}
    {% include 'social_layer/posts/local_posts_feed_header.html' %}
{% endblock header%}

{% block content %}
    {% include 'social_layer/posts/local_posts_feed_top.html' %}
    {% include 'social_layer/posts/post_form.html' %}
    {% if not request.user.is_authenticated %}
    <script async application="javascript">
        var txt = document.getElementById('id_text');
        txt.addEventListener('focus', (event) => {
            window.location = "{% url 'social_layer:social_login' %}";
            }, true);
    </script>
    {% endif %}
    {% for post in feed %}
        {% include 'social_layer/posts/render_post.html' %}
    {% endfor %}
    {% infinite_scroll_box %}
    {% include 'social_layer/comments/reply_mod.html' %}
    {% set_infinite_scroll %}
{% endblock content %}
